@@ -11,6 +11,7 @@
 // Journal Entry
 
 #include "journalframe.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <Akonadi/CalendarUtils>
 #include <CalendarSupport/Utils>
@@ -35,7 +36,7 @@ JournalDateView::JournalDateView(const Akonadi::CollectionCalendar::Ptr &calenda
     , mCalendar(calendar)
 {
     auto layout = new QVBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
     layout->setSpacing(0);
 }
 
@@ -148,7 +149,7 @@ JournalFrame::JournalFrame(const Akonadi::Item &j, const Akonadi::CollectionCale
     buttonsLayout->addStretch();
 
     mEditButton = new QPushButton(this);
-    mEditButton->setObjectName(QLatin1StringView("editButton"));
+    mEditButton->setObjectName("editButton"_L1);
     mEditButton->setText(i18n("&Edit"));
     mEditButton->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
     mEditButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
@@ -158,7 +159,7 @@ JournalFrame::JournalFrame(const Akonadi::Item &j, const Akonadi::CollectionCale
     connect(mEditButton, &QPushButton::clicked, this, &JournalFrame::editItem);
 
     mDeleteButton = new QPushButton(this);
-    mDeleteButton->setObjectName(QLatin1StringView("deleteButton"));
+    mDeleteButton->setObjectName("deleteButton"_L1);
     mDeleteButton->setText(i18n("&Delete"));
     mDeleteButton->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
     mDeleteButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
@@ -169,7 +170,7 @@ JournalFrame::JournalFrame(const Akonadi::Item &j, const Akonadi::CollectionCale
 
     mPrintButton = new QPushButton(this);
     mPrintButton->setText(i18n("&Print"));
-    mPrintButton->setObjectName(QLatin1StringView("printButton"));
+    mPrintButton->setObjectName("printButton"_L1);
     mPrintButton->setIcon(QIcon::fromTheme(QStringLiteral("document-print")));
     mPrintButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     mPrintButton->setToolTip(i18n("Print this journal entry"));
@@ -179,7 +180,7 @@ JournalFrame::JournalFrame(const Akonadi::Item &j, const Akonadi::CollectionCale
 
     mPrintPreviewButton = new QPushButton(this);
     mPrintPreviewButton->setText(i18n("Print preview"));
-    mPrintPreviewButton->setObjectName(QLatin1StringView("printButton"));
+    mPrintPreviewButton->setObjectName("printButton"_L1);
     mPrintPreviewButton->setIcon(QIcon::fromTheme(QStringLiteral("document-print-preview")));
     mPrintPreviewButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     mPrintPreviewButton->setToolTip(i18n("Print preview this journal entry"));
